SNAP
====

Processing
----------

.. automodule:: pyroSAR.snap.util
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        geocode
        noise_power

Workflow Parsing and Execution
------------------------------

.. automodule:: pyroSAR.snap.auxil
    :members: gpt, execute, parse_node, parse_recipe, split, groupbyWorkers, Workflow, Node, Par, Par_BandMath, dem_parametrize, geo_parametrize, mli_parametrize, orb_parametrize, sub_parametrize
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        gpt
        execute
        parse_node
        parse_recipe
        split
        groupbyWorkers
        Workflow
        Node
        Par
        Par_BandMath
        dem_parametrize
        geo_parametrize
        mli_parametrize
        orb_parametrize
        sub_parametrize

General Utilities
-----------------

.. automodule:: pyroSAR.snap.auxil
    :members: erode_edges, writer
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        erode_edges
        writer
